@@ -19,32 +19,6 @@ class EC2Mixin(object):
         data.update(get_instance_metadata())
         return data
 
-    def acquire_master_cname(self, force=False):
-        """ Use Route53 to update the master_cname record to point to this instance.
-
-            If the CNAME already exists and force is False, an exception will be raised.
-            Setting force to True will cause this function to 'take' the DNS record.
-        """
-        raise NotImplementedError
-
-    def add_to_slave_cname_pool(self):
-        """ Add this instance to the slave_cname weighted resource record DNS pool.
-        """
-        raise NotImplementedError
-
-
-class VagrantMixin(object):
-    def get_metadata(self):
-        data = os.environ
-        data['cluster'] = 'vagranttest'
-        data['public_hostname'] = 'instance12346.vagranttest.example.com'
-        data['instance_id'] = 'i-12346'
-        return data
-
-    def _get_route53_conn(self):
-        return boto.connect_route53(aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
-            aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY)
-
     def acquire_master_cname(self, force=False):
         # TODO move this to EC2Mixin after initial testing
         """ Use Route53 to update the master_cname record to point to this instance.
@@ -110,6 +84,20 @@ class VagrantMixin(object):
         self.logger.info('Finished updating DNS records')
 
 
+class VagrantMixin(object):
+    def get_metadata(self):
+        data = os.environ
+        data['cluster'] = 'vagranttest'
+        data['public_hostname'] = 'instance12346.vagranttest.example.com'
+        data['instance_id'] = 'i-12346'
+        return data
+
+    def _get_route53_conn(self):
+        return boto.connect_route53(aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
+            aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY)
+
+
+
 def get_cluster_class(infrastructureClass, serviceClass):
     clusterClass = type('className', (serviceClass, infrastructureClass), {})
     return clusterClass
@@ -246,8 +234,7 @@ class ScriptCluster(BaseCluster):
         self.process_started()
 
 
-#class PostgresqlCluster(EC2Mixin, BaseCluster):
-class PostgresqlCluster(VagrantMixin, BaseCluster):
+class PostgresqlCluster(EC2Mixin, BaseCluster):
     """ PostgreSQL cluster.
 
         Master: Starts postgres normally
